==> analitza-24.08.2-x86_64-1_KDE6.txz: usr/lib64/cmake/Analitza6/Analitza6Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6::Analitza" for configuration "Release"
set_property(TARGET KF6::Analitza APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::Analitza PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libAnalitza.so.9.0.0"
  IMPORTED_SONAME_RELEASE "libAnalitza.so.9"
  )

list(APPEND _cmake_import_check_targets KF6::Analitza )
list(APPEND _cmake_import_check_files_for_KF6::Analitza "${_IMPORT_PREFIX}/lib64/libAnalitza.so.9.0.0" )

# Import target "KF6::AnalitzaPlot" for configuration "Release"
set_property(TARGET KF6::AnalitzaPlot APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::AnalitzaPlot PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::PrintSupport;Qt6::OpenGL"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libAnalitzaPlot.so.9.0.0"
  IMPORTED_SONAME_RELEASE "libAnalitzaPlot.so.9"
  )

list(APPEND _cmake_import_check_targets KF6::AnalitzaPlot )
list(APPEND _cmake_import_check_files_for_KF6::AnalitzaPlot "${_IMPORT_PREFIX}/lib64/libAnalitzaPlot.so.9.0.0" )

# Import target "KF6::AnalitzaGui" for configuration "Release"
set_property(TARGET KF6::AnalitzaGui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::AnalitzaGui PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libAnalitzaGui.so.9.0.0"
  IMPORTED_SONAME_RELEASE "libAnalitzaGui.so.9"
  )

list(APPEND _cmake_import_check_targets KF6::AnalitzaGui )
list(APPEND _cmake_import_check_files_for_KF6::AnalitzaGui "${_IMPORT_PREFIX}/lib64/libAnalitzaGui.so.9.0.0" )

# Import target "KF6::AnalitzaWidgets" for configuration "Release"
set_property(TARGET KF6::AnalitzaWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::AnalitzaWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::OpenGLWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libAnalitzaWidgets.so.9.0.0"
  IMPORTED_SONAME_RELEASE "libAnalitzaWidgets.so.9"
  )

list(APPEND _cmake_import_check_targets KF6::AnalitzaWidgets )
list(APPEND _cmake_import_check_files_for_KF6::AnalitzaWidgets "${_IMPORT_PREFIX}/lib64/libAnalitzaWidgets.so.9.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> analitza-24.08.3-x86_64-14.1_KDE6.txz: usr/lib64/cmake/Analitza6/Analitza6Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF6::Analitza" for configuration "Release"
set_property(TARGET KF6::Analitza APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::Analitza PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Xml"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libAnalitza.so.9.0.0"
  IMPORTED_SONAME_RELEASE "libAnalitza.so.9"
  )

list(APPEND _cmake_import_check_targets KF6::Analitza )
list(APPEND _cmake_import_check_files_for_KF6::Analitza "${_IMPORT_PREFIX}/lib64/libAnalitza.so.9.0.0" )

# Import target "KF6::AnalitzaPlot" for configuration "Release"
set_property(TARGET KF6::AnalitzaPlot APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::AnalitzaPlot PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::PrintSupport;Qt6::OpenGL"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libAnalitzaPlot.so.9.0.0"
  IMPORTED_SONAME_RELEASE "libAnalitzaPlot.so.9"
  )

list(APPEND _cmake_import_check_targets KF6::AnalitzaPlot )
list(APPEND _cmake_import_check_files_for_KF6::AnalitzaPlot "${_IMPORT_PREFIX}/lib64/libAnalitzaPlot.so.9.0.0" )

# Import target "KF6::AnalitzaGui" for configuration "Release"
set_property(TARGET KF6::AnalitzaGui APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::AnalitzaGui PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libAnalitzaGui.so.9.0.0"
  IMPORTED_SONAME_RELEASE "libAnalitzaGui.so.9"
  )

list(APPEND _cmake_import_check_targets KF6::AnalitzaGui )
list(APPEND _cmake_import_check_files_for_KF6::AnalitzaGui "${_IMPORT_PREFIX}/lib64/libAnalitzaGui.so.9.0.0" )

# Import target "KF6::AnalitzaWidgets" for configuration "Release"
set_property(TARGET KF6::AnalitzaWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF6::AnalitzaWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Svg;Qt6::OpenGLWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libAnalitzaWidgets.so.9.0.0"
  IMPORTED_SONAME_RELEASE "libAnalitzaWidgets.so.9"
  )

list(APPEND _cmake_import_check_targets KF6::AnalitzaWidgets )
list(APPEND _cmake_import_check_files_for_KF6::AnalitzaWidgets "${_IMPORT_PREFIX}/lib64/libAnalitzaWidgets.so.9.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
